@@ -38,40 +38,28 @@
 
 
 /**
-   File Name:          15.9.5.10.js
-   ECMA Section:       15.9.5.10
-   Description:        Date.prototype.getDate
+   File Name:          15.9.5.12.js
+   ECMA Section:       15.9.5.12
+   Description:        Date.prototype.getDay
 
-   1.Let t be this time value.
-   2.If t is NaN, return NaN.
-   3.Return DateFromTime(LocalTime(t)).
+
+   1.   Let t be this time value.
+   2.   If t is NaN, return NaN.
+   3.   Return WeekDay(LocalTime(t)).
 
    Author:             christine@netscape.com
    Date:               12 november 1997
 */
 
-var SECTION = "15.9.5.10";
+var SECTION = "15.9.5.12";
 var VERSION = "ECMA_1";
 startTest();
-var TITLE   = "Date.prototype.getDate()";
+var TITLE   = "Date.prototype.getDay()";
 
 writeHeaderToLog( SECTION + " "+ TITLE);
 
-// some daylight savings time cases
+addTestCase( TIME_0000 );
 
-var DST_END_1998 = GetDSTEnd(TimeFromYear(1998));
-
-addTestCase( DST_END_1998-1 );
-
-new TestCase( SECTION,
-	      "(new Date(NaN)).getDate()",
-	      NaN,
-	      (new Date(NaN)).getDate() );
-
-new TestCase( SECTION,
-	      "Date.prototype.getDate.length",
-	      0,
-	      Date.prototype.getDate.length );
 test();
 
 function addTestCase( t ) {
@@ -81,8 +69,8 @@ function addTestCase( t ) {
   for (var d = start; d < stop; d += msPerDay)
   {
     new TestCase( SECTION,
-                  "(new Date("+d+")).getDate()",
-                  DateFromTime(LocalTime(d)),
-                  (new Date(d)).getDate() );
+                  "(new Date("+d+")).getDay()",
+                  WeekDay((LocalTime(d))),
+                  (new Date(d)).getDay() );
   }
 }
